// This file is an automatically generated file, please do not edit this file, modify the WrapperGenerator.java file instead !

package sun.awt.X11;

import sun.misc.*;

import java.util.logging.*;
public class XIconSize extends XWrapperBase { 
	private Unsafe unsafe = XlibWrapper.unsafe; 
	private final boolean should_free_memory;
	public static int getSize() { return 24; }
	public int getDataSize() { return getSize(); }

	long pData;

	public long getPData() { return pData; }


	XIconSize(long addr) {
		log.finest("Creating");
		pData=addr;
		should_free_memory = false;
	}


	XIconSize() {
		log.finest("Creating");
		pData = unsafe.allocateMemory(getSize());
		should_free_memory = true;
	}


	public void dispose() {
		log.finest("Disposing");
		if (should_free_memory) {
			log.finest("freeing memory");
			unsafe.freeMemory(pData); 
	}
		}
	public int get_min_width() { log.finest("");return (Native.getInt(pData+0)); }
	public void set_min_width(int v) { log.finest(""); Native.putInt(pData+0, v); }
	public int get_min_height() { log.finest("");return (Native.getInt(pData+4)); }
	public void set_min_height(int v) { log.finest(""); Native.putInt(pData+4, v); }
	public int get_max_width() { log.finest("");return (Native.getInt(pData+8)); }
	public void set_max_width(int v) { log.finest(""); Native.putInt(pData+8, v); }
	public int get_max_height() { log.finest("");return (Native.getInt(pData+12)); }
	public void set_max_height(int v) { log.finest(""); Native.putInt(pData+12, v); }
	public int get_width_inc() { log.finest("");return (Native.getInt(pData+16)); }
	public void set_width_inc(int v) { log.finest(""); Native.putInt(pData+16, v); }
	public int get_height_inc() { log.finest("");return (Native.getInt(pData+20)); }
	public void set_height_inc(int v) { log.finest(""); Native.putInt(pData+20, v); }


	String getName() {
		return "XIconSize"; 
	}


	String getFieldsAsString() {
		String ret="";

		ret += ""+"min_width = " + get_min_width() +", ";
		ret += ""+"min_height = " + get_min_height() +", ";
		ret += ""+"max_width = " + get_max_width() +", ";
		ret += ""+"max_height = " + get_max_height() +", ";
		ret += ""+"width_inc = " + get_width_inc() +", ";
		ret += ""+"height_inc = " + get_height_inc() +", ";
		return ret;
	}


}



